| PipeOpMean_B | R Documentation |
Impute numerical features by their mean in approach B (independently during the training and prediction phase).
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_mean_B".
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> Mean_B_imputation
new()PipeOpMean_B$new(id = "impute_mean_B", param_vals = list())
clone()The objects of this class are cloneable with this method.
PipeOpMean_B$clone(deep = FALSE)
deepWhether to make a deep clone.
# Using debug learner for example purpose
graph <- PipeOpMean_B$new() %>>% LearnerClassifDebug$new()
graph_learner <- GraphLearner$new(graph)
set.seed(1)
resample(tsk("pima"), graph_learner, rsmp("cv", folds = 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.