| PipeOpVIM_IRMI | R Documentation |
Implements IRMI methods as mlr3 pipeline, more about VIM_IRMI autotune_VIM_Irmi.
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_VIM_IRMI".
eps :: double(1)
Threshold for convergence, default 5.
maxit :: integer(1)
Maximum number of iterations, default 100
step :: logical(1)
Stepwise model selection is applied when the parameter is set to TRUE, default FALSE.
robust :: logical(1)
If TRUE, robust regression methods will be applied (it's impossible to set step=TRUE and robust=TRUE at the same time), default FALSE.
init.method :: character(1)
Method for initialization of missing values (kNN or median), default 'kNN'.
force :: logical(1)
If TRUE, the algorithm tries to find a solution in any case by using different robust methods automatically (should be set FALSE for simulation), default FALSE.
out_fill :: character(1)
Output log file location. If file already exists log message will be added. If NULL no log will be produced, default NULL.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> VIM_IRMI_imputation
new()PipeOpVIM_IRMI$new( id = "impute_VIM_IRMI_B", eps = 5, maxit = 100, step = FALSE, robust = FALSE, init.method = "kNN", force = FALSE, out_file = NULL )
clone()The objects of this class are cloneable with this method.
PipeOpVIM_IRMI$clone(deep = FALSE)
deepWhether to make a deep clone.
graph <- PipeOpVIM_IRMI$new() %>>% mlr3learners::LearnerClassifGlmnet$new()
graph_learner <- GraphLearner$new(graph)
# Task with NA
resample(TaskClassif$new('id',tsk('pima')$data(rows=1:100),
'diabetes'), graph_learner, rsmp("cv",folds=2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.