| PipeOpVIM_regrImp | R Documentation |
Implements Regression Imputation methods as mlr3 pipeline, more about RI autotune_VIM_regrImp.
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_VIM_regrImp".
robust :: logical(1)
TRUE/FALSE: whether to use robust regression, default FALSE.
mod_cat :: logical(1)
TRUE/FALSE if TRUE for categorical variables the level with the highest prediction probability is selected, otherwise it is sampled according to the probabilities, default FALSE.
use_imputed :: logical(1)
TRUE/FALSe: if TURE, already imputed columns will be used to impute others, default FALSE.
out_fill :: character(1)
Output log file location. If file already exists log message will be added. If NULL no log will be produced, default NULL.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> VIM_regrImp_imputation
new()PipeOpVIM_regrImp$new( id = "impute_VIM_regrImp_B", robust = FALSE, mod_cat = FALSE, use_imputed = FALSE, out_file = NULL )
clone()The objects of this class are cloneable with this method.
PipeOpVIM_regrImp$clone(deep = FALSE)
deepWhether to make a deep clone.
{
graph <- PipeOpVIM_regrImp$new() %>>% mlr3learners::LearnerClassifGlmnet$new()
graph_learner <- GraphLearner$new(graph)
# Task with NA
resample(tsk("pima"), graph_learner, rsmp("cv", folds = 3))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.