| PipeOpmissForest | R Documentation |
Implements missForest methods as mlr3 pipeline more about missForest autotune_missForest
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_missForest".
cores :: integer(1)
Number of threads used by parallel calculations. If NULL approximately half of available CPU cores will be used, default NULL.
ntree_set :: integer(1)
Vector with number of trees values for grid search, used only when optimize=TRUE, default c(100,200,500,1000).
mtry_set :: integer(1)
Vector with number of variables values randomly sampled at each split, used only when optimize=TRUE, default NULL.
parallel :: logical(1)
If TRUE parallel calculations are used, default FALSE.
ntree :: integer(1)
ntree from missForest function, default 100.
optimize :: logical(1)
If set TRUE, function will optimize parameters of imputation automatically. If parameters will be tuned by other method, should be set to FALSE, default FALSE.
mtry :: integer(1)
mtry from missForest function, default NULL.
maxiter :: integer(1)
maxiter from missForest function, default 20.
maxnodes :: character(1)
maxnodes from missForest function, default NULL
out_fill :: character(1)
Output log file location. If file already exists log message will be added. If NULL no log will be produced, default NULL.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> missForest_imputation
new()PipeOpmissForest$new( id = "impute_missForest_B", cores = NULL, ntree_set = c(100, 200, 500, 1000), mtry_set = NULL, parallel = FALSE, mtry = NULL, ntree = 100, optimize = FALSE, maxiter = 20, maxnodes = NULL, out_file = NULL )
clone()The objects of this class are cloneable with this method.
PipeOpmissForest$clone(deep = FALSE)
deepWhether to make a deep clone.
# Using debug learner for example purpose
graph <- PipeOpmissForest$new() %>>% LearnerClassifDebug$new()
graph_learner <- GraphLearner$new(graph)
# Task with NA
resample(tsk("pima"), graph_learner, rsmp("cv", folds = 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.