| PipeOpmissMDA_MFA | R Documentation |
Implements MFA methods as mlr3 pipeline, more about MFA missMDA_MFA.
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_missMDA_MFA".
ncp :: integer(1)
Number of dimensions used by algorithm, default 2.
random.seed :: integer(1)
Integer, by default random.seed = NULL implies that missing values are initially imputed by the mean of each variable. Other values leads to a random initialization, default NULL.
maxiter :: integer(1)
Maximal number of iteration in algorithm, default 998.
coeff.ridge :: integer(1)
Value used in Regularized method, default 1.
threshold :: double(1)
Threshold for convergence, default 1e-06.
method :: character(1)
Method used in imputation algorithm, default 'Regularized'.
out_fill :: character(1)
Output log file location. If file already exists log message will be added. If NULL no log will be produced, default NULL.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> missMDA_MFAimputation
new()PipeOpMissMDA_MFA$new( id = "impute_missMDA_MFA_B", ncp = 2, random.seed = NULL, maxiter = 998, coeff.ridge = 1, threshold = 1e-06, method = "Regularized", out_file = NULL )
clone()The objects of this class are cloneable with this method.
PipeOpMissMDA_MFA$clone(deep = FALSE)
deepWhether to make a deep clone.
# Using debug learner for example purpose
graph <- PipeOpMissMDA_MFA$new() %>>% LearnerClassifDebug$new()
graph_learner <- GraphLearner$new(graph)
# Task with NA
resample(tsk("pima"), graph_learner, rsmp("cv", folds = 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.