| PipeOpmissMDA_PCA_MCA_FMAD_A | R Documentation |
Implements PCA, MCA, FMAD methods as mlr3 pipeline in approach A, more about methods missMDA_FMAD_MCA_PCA and missMDA.reuse
Input and output channels are inherited from PipeOpImpute.
The parameters include inherited from ['PipeOpImpute'], as well as:
id :: character(1)
Identifier of resulting object, default "imput_missMDA_MCA_PCA_FMAD".
optimize_ncp :: logical(1)
If TRUE, parameter number of dimensions, used to predict the missing values, will be optimized. If FALSE, by default ncp=2 is used, default TRUE.
set_ncp :: integer(1)
integer >0. Number of dimensions used by algortims. Used only if optimize_ncp = Flase, default 2.
ncp.max :: integer(1)
Number corresponding to the maximum number of components to test when optimize_ncp=TRUE, default 5.
random.seed :: integer(1)
Integer, by default random.seed = NULL implies that missing values are initially imputed by the mean of each variable. Other values leads to a random initialization, default NULL.
maxiter :: integer(1)
Maximal number of iteration in algorithm, default 998.
coeff.ridge :: double(1)
Value used in Regularized method, default 1.
threshold :: double(1)
Threshold for convergence, default 1e-6.
method :: character(1)
Method used in imputation algorithm, default 'Regularized'.
out_fill :: character(1)
Output log file location. If file already exists log message will be added. If NULL no log will be produced, default NULL.
mlr3pipelines::PipeOp -> mlr3pipelines::PipeOpImpute -> missMDA_MCA_PCA_FMAD_imputation_A
new()PipeOpMissMDA_PCA_MCA_FMAD_A$new( id = "impute_missMDA_MCA_PCA_FMAD_A", optimize_ncp = TRUE, set_ncp = 2, ncp.max = 5, random.seed = NULL, maxiter = 998, coeff.ridge = 1, threshold = 1e-06, method = "Regularized", out_file = NULL )
clone()The objects of this class are cloneable with this method.
PipeOpMissMDA_PCA_MCA_FMAD_A$clone(deep = FALSE)
deepWhether to make a deep clone.
# Using debug learner for example purpose
graph <- PipeOpMissMDA_PCA_MCA_FMAD_A$new() %>>% LearnerClassifDebug$new()
graph_learner <- GraphLearner$new(graph)
# Task with NA
set.seed(1)
resample(tsk("pima"), graph_learner, rsmp("cv", folds = 3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.